VibeSurf Extension

#### Welcome to VibeSurf

Let's vibe surfing the internet with AI automation

🔍
Research Founders
Search information about browser-use and browser-use-webui, write a brief report
📰
HackerNews Summary
Get top 10 news from HackerNews and provide a summary
📈
Stock Market Analysis
Analyze recent week stock market trends for major tech companies

### Chat History

#### Recent Tasks

Last 3 sessions

#### All Sessions

Page 1 of 1

### VibeSurf Settings

Environment Variables

### Add LLM Profile

Connecting to VibeSurf...